# Botocore Documentation

Documentation for botocore can be found [here](https://botocore.amazonaws.com/v1/documentation/api/latest/index.html)

## Generating Documentation

Sphinx is used for documentation. You can generate HTML locally with the
following:

```
$ pip install -r requirements-docs.txt
$ cd docs
$ make html
```
